@@ -16,6 +16,8 @@
 /// General math traits.
 pub use num_traits as traits;
 
+/// Interfaces to either conver or reinterpret nath data structure as analog of math lib of choice..
+pub mod as_native;
 /// Local implementation of traits From / Into. Required because of limmitations of Rust.
 pub mod from;
 /// Implementation of adapters for specific math libraries.
@@ -45,6 +47,7 @@ pub mod dependency
 /// Exposed namespace of the module.
 pub mod exposed
 {
+  pub use super::as_native::exposed::*;
   pub use super::from::exposed::*;
   pub use super::plugin::exposed::*;
   pub use super::scalar::exposed::*;
@@ -56,6 +59,7 @@ pub use exposed::*;
 /// Prelude to use: `use wtools::prelude::*`.
 pub mod prelude
 {
+  pub use super::as_native::prelude::*;
   pub use super::from::prelude::*;
   pub use super::plugin::prelude::*;
   pub use super::scalar::prelude::*;
