@@ -1,6 +1,9 @@
 
 /// Basics.
 pub mod x2;
+pub use x2::macros;
+#[ allow( unused_imports ) ]
+pub( crate ) use x2::macros::*;
 
 /// Exposed namespace of the module.
 pub mod exposed
